@@ -5,6 +5,7 @@ import logging
 import logging.handlers
 import os
 import time
+from decimal import Decimal
 from uuid import uuid4
 from twisted.internet import reactor
 from twisted.internet.threads import deferToThread
@@ -436,6 +437,7 @@ class BaseServer(object):
         cost = (self.sdb.box_usage * .14) * (60*60*24*30.4) / (running_time)
         active_requests_by_host = self.rq.getActiveRequestsByHost()
         pending_requests_by_host = self.rq.getPendingRequestsByHost()
+        load_average = [str(Decimal(str(x), 2)) for x in os.getloadavg()]
         data = {
             "load_avg":os.getloadavg(),
             "running_time":running_time,
