@@ -35,7 +35,7 @@ class ExecutionServer(BaseServer):
     querying_for_jobs = False
     reservation_update_queue = []
     current_sql = ""
-    
+    last_job_query_count = 0
     def __init__(self,
             aws_access_key_id, 
             aws_secret_access_key, 
@@ -224,7 +224,10 @@ class ExecutionServer(BaseServer):
             "pending_requests":server_data["pending_requests"],
             "current_timestamp":server_data["current_timestamp"],
             "job_queue":len(self.job_queue),
-            "current_sql":self.current_sql.replace("\n", "")}
+            "active_jobs":len(self.active_jobs),
+            "queued_jobs":len(self.queued_jobs),
+            "current_sql":self.current_sql.replace("\n", ""),
+            "last_job_query_count":self.last_job_query_count}
         if self.uuid_limits["start"] is None and self.uuid_limits["end"] is not None:
             attributes["range"] = "Start - %s" % self.uuid_limits["end"]
         elif self.uuid_limits["start"] is not None and self.uuid_limits["end"] is None:
@@ -479,6 +482,7 @@ class ExecutionServer(BaseServer):
         LOGGER.info("Fetched %s jobs." % len(data))
         self.querying_for_jobs = False
         # Iterate through the reservation data returned from SimpleDB
+        self.last_job_query_count = len(data)
         for uuid in data:
             if uuid in self.active_jobs or uuid in self.queued_jobs:
                 continue
